<?php

namespace App\Entity;

use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Delete;
use ApiPlatform\Metadata\Patch;
use ApiPlatform\Metadata\Put;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Metadata\ApiFilter;
use App\Repository\DemandeRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Serializer\Annotation\Groups;
/**
 * @ORM\Entity (repositoryClass=DemandeRepository::class)
 */
#[ApiResource(normalizationContext: ['groups' => ['read:Demande']], denormalizationContext: ['groups' => ['write:Demande']])]
#[ApiFilter(SearchFilter::class, properties: ['id' => 'exact'])]
class Demande
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     * @Groups({"read:Demande","read:User"})
     */
    private $id;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $titre;
    /**
     * @ORM\Column(type="string", length=2000, nullable=true)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $description;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $montant;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $apport;
    /**
     * @ORM\Column(type="string", length=500, nullable=true)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $justif;
    /**
     * @ORM\ManyToOne(targetEntity=User::class, inversedBy="demandes")
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $user;
    /**
     * @ORM\OneToMany(targetEntity=Paiement::class, mappedBy="demande")
     * @Groups({"read:Demande","read:User"})
     */
    private $paiements;
    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $statut;
    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read:Demande","write:Demande","read:User"})
     */
    private $benefices;
    public function __construct()
    {
        $this->paiements = new ArrayCollection();
    }
    public function getId() : ?int
    {
        return $this->id;
    }
    public function getTitre() : ?string
    {
        return $this->titre;
    }
    public function setTitre(?string $titre) : self
    {
        $this->titre = $titre;
        return $this;
    }
    public function getDescription() : ?string
    {
        return $this->description;
    }
    public function setDescription(?string $description) : self
    {
        $this->description = $description;
        return $this;
    }
    public function getMontant() : ?string
    {
        return $this->montant;
    }
    public function setMontant(?string $montant) : self
    {
        $this->montant = $montant;
        return $this;
    }
    public function getApport() : ?string
    {
        return $this->apport;
    }
    public function setApport(?string $apport) : self
    {
        $this->apport = $apport;
        return $this;
    }
    public function getJustif() : ?string
    {
        return $this->justif;
    }
    public function setJustif(?string $justif) : self
    {
        $this->justif = $justif;
        return $this;
    }
    public function getUser() : ?User
    {
        return $this->user;
    }
    public function setUser(?User $user) : self
    {
        $this->user = $user;
        return $this;
    }
    /**
     * @return Collection|Paiement[]
     */
    public function getPaiements() : Collection
    {
        return $this->paiements;
    }
    public function addPaiement(Paiement $paiement) : self
    {
        if (!$this->paiements->contains($paiement)) {
            $this->paiements[] = $paiement;
            $paiement->setDemande($this);
        }
        return $this;
    }
    public function removePaiement(Paiement $paiement) : self
    {
        if ($this->paiements->removeElement($paiement)) {
            // set the owning side to null (unless already changed)
            if ($paiement->getDemande() === $this) {
                $paiement->setDemande(null);
            }
        }
        return $this;
    }
    public function getStatut() : ?string
    {
        return $this->statut;
    }
    public function setStatut(string $statut) : self
    {
        $this->statut = $statut;
        return $this;
    }
    public function getBenefices() : ?string
    {
        return $this->benefices;
    }
    public function setBenefices(string $benefices) : self
    {
        $this->benefices = $benefices;
        return $this;
    }
}
