<?php

namespace App\Entity;

use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Delete;
use ApiPlatform\Metadata\Patch;
use ApiPlatform\Metadata\Put;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Metadata\ApiFilter;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Security\Core\User\PasswordAuthenticatedUserInterface;
use Symfony\Component\Security\Core\User\UserInterface;
use Symfony\Component\Serializer\Annotation\Groups;
use App\Repository\UserRepository;
/**
 * @ORM\Entity (repositoryClass=UserRepository::class)
 * @ORM\Table (name="`user`")
 */
#[ApiResource(normalizationContext: ['groups' => ['read:User']], denormalizationContext: ['groups' => ['write:User']])]
#[ApiFilter(SearchFilter::class, properties: ['email' => 'exact'])]
class User
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     * @Groups({"read:User","read:Demande"})
     */
    private $id;
    /**
     * @ORM\Column(type="string", length=180, unique=true)
     * @Groups({"read:User","write:User","read:Demande"})
     */
    private $email;
    /**
     * @ORM\Column(type="json")
     * @Groups({"read:User", "write:User"})
     */
    private $roles = [];
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:User","write:User","read:Demande"})
     */
    private $nom;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:User","write:User","read:Demande"})
     */
    private $prenom;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:User","write:User","read:Demande"})
     */
    private $telephone;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:User","write:User"})
     */
    private $adresse;
    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read:User","write:User"})
     */
    private $profession;
    /**
     * @ORM\OneToMany(targetEntity=Demande::class, mappedBy="user")
     * @Groups({"read:User"})
     */
    private $demandes;
    
    /**
     * @ORM\OneToMany(targetEntity=Card::class, mappedBy="user")
     * @Groups({"read:User"})
     */
    private $cards;
    
    /**
     * @ORM\OneToMany(targetEntity=Boutique::class, mappedBy="volontaire")
     * @Groups({"read:User"})
     */
    private $boutiques;
    
    public function __construct()
    {
        $this->demandes = new ArrayCollection();
        $this->cards = new ArrayCollection();
        $this->boutiques = new ArrayCollection();
    }
    public function getId() : ?int
    {
        return $this->id;
    }
    public function getEmail() : ?string
    {
        return $this->email;
    }
    public function setEmail(string $email) : self
    {
        $this->email = $email;
        return $this;
    }
    /**
     * A visual identifier that represents this user.
     *
     * @see UserInterface
     */
    public function getUserIdentifier() : string
    {
        return (string) $this->email;
    }
    /**
     * @deprecated since Symfony 5.3, use getUserIdentifier instead
     */
    public function getUsername() : string
    {
        return (string) $this->email;
    }
    /**
     * @see UserInterface
     */
    public function getRoles() : array
    {
        $roles = $this->roles;
        // guarantee every user at least has ROLE_USER
        $roles[] = 'ROLE_USER';
        return array_unique($roles);
    }
    public function setRoles(array $roles) : self
    {
        $this->roles = $roles;
        return $this;
    }
    public function getAdresse() : ?string
    {
        return $this->adresse;
    }
    public function setAdresse(?string $adresse) : self
    {
        $this->adresse = $adresse;
        return $this;
    }
    public function getNom() : ?string
    {
        return $this->nom;
    }
    public function setNom(?string $nom) : self
    {
        $this->nom = $nom;
        return $this;
    }
    public function getPrenom() : ?string
    {
        return $this->prenom;
    }
    public function setPrenom(?string $prenom) : self
    {
        $this->prenom = $prenom;
        return $this;
    }
    public function getTelephone() : ?string
    {
        return $this->telephone;
    }
    public function setTelephone(?string $telephone) : self
    {
        $this->telephone = $telephone;
        return $this;
    }
    public function getProfession() : ?string
    {
        return $this->profession;
    }
    public function setProfession(?string $profession) : self
    {
        $this->profession = $profession;
        return $this;
    }

    /**
     * @return Collection|Demande[]
     */
    public function getDemandes() : Collection
    {
        return $this->demandes;
    }
    public function addDemande(Demande $demande) : self
    {
        if (!$this->demandes->contains($demande)) {
            $this->demandes[] = $demande;
            $demande->setUser($this);
        }
        return $this;
    }
    public function removeDemande(Demande $demande) : self
    {
        if ($this->demandes->removeElement($demande)) {
            // set the owning side to null (unless already changed)
            if ($demande->getUser() === $this) {
                $demande->setUser(null);
            }
        }
        return $this;
    }
    
    
    
    
    /**
     * @return Collection|Card[]
     */
    public function getCards() : Collection
    {
        return $this->cards;
    }
    public function addCard(Card $card) : self
    {
        if (!$this->cards->contains($card)) {
            $this->cards[] = $card;
            $card->setUser($this);
        }
        return $this;
    }
    public function removeCard(Card $card) : self
    {
        if ($this->cards->removeElement($card)) {
            // set the owning side to null (unless already changed)
            if ($card->getUser() === $this) {
                $card->setUser(null);
            }
        }
        return $this;
    }
    
    
    
        /**
     * @return Collection|Boutique[]
     */
    public function getBoutiques() : Collection
    {
        return $this->boutiques;
    }
    public function addBoutique(Boutique $boutique) : self
    {
        if (!$this->boutiques->contains($boutique)) {
            $this->boutiques[] = $boutique;
            $boutique->setUser($this);
        }
        return $this;
    }
    public function removeBoutique(Boutique $boutique) : self
    {
        if ($this->boutiques->removeElement($boutique)) {
            // set the owning side to null (unless already changed)
            if ($boutique->getUser() === $this) {
                $boutique->setUser(null);
            }
        }
        return $this;
    }
    
    
    
}
